@@ -32,10 +32,6 @@
 #endif
 
 #ifdef _WIN32
-#ifdef __MINGW32__
-// MinGW enables definition of getaddrinfo et al only if WINVER >= 0x0501.
-#define WINVER 0x0501
-#endif
 #include <winsock2.h>
 #include <ws2tcpip.h>
 #endif
@@ -261,11 +257,17 @@ static JSClass global_class = {
 };
 
 // Set my (client's) IP address to a custom value.
-void
+int
 pacparser_setmyip(const char *ip)
 {
+  if (strlen(ip) > INET6_ADDRSTRLEN) {
+    fprintf(stderr, "pacparser_setmyip: IP too long: %s\n", ip);
+    return 0;
+  }
+
   myip = malloc(strlen(ip) +1);         // Allocate space just to be sure.
   strcpy(myip, ip);
+  return 1;
 }
 
 // Decprecated: This function doesn't do anything.
@@ -402,8 +404,8 @@ pacparser_parse_pac(const char *pacfile)
 
 // Finds proxy for the given URL and Host.
 //
-// If JavaScript engine is intialized and FindProxyForURL function is defined,
-// it evaluates code FindProxyForURL(url,host) in JavaScript context and
+// If JavaScript engine is intialized and findProxyForURL function is defined,
+// it evaluates code findProxyForURL(url,host) in JavaScript context and
 // returns the result.
 char *                                  // Proxy string or NULL if failed.
 pacparser_find_proxy(const char *url, const char *host)
@@ -425,13 +427,13 @@ pacparser_find_proxy(const char *url, const char *host)
     print_error("%s %s\n", error_prefix, "Pac parser is not initialized.");
     return NULL;
   }
-  // Test if FindProxyForURL is defined.
-  script = "typeof(FindProxyForURL);";
+  // Test if findProxyForURL is defined.
+  script = "typeof(findProxyForURL);";
   if (_debug()) print_error("DEBUG: Executing JavaScript: %s\n", script);
   JS_EvaluateScript(cx, global, script, strlen(script), NULL, 1, &rval);
   if (strcmp("function", JS_GetStringBytes(JS_ValueToString(cx, rval))) != 0) {
     print_error("%s %s\n", error_prefix,
-		  "Javascript function FindProxyForURL not defined.");
+		  "Javascript function findProxyForURL not defined.");
     return NULL;
   }
 
@@ -440,20 +442,20 @@ pacparser_find_proxy(const char *url, const char *host)
   // Hostname shouldn't have single quotes in them
   if (strchr(host, '\'')) {
     print_error("%s %s\n", error_prefix,
-		"Invalid hostname: hostname can't have single quotes.");
+      "Invalid hostname: hostname can't have single quotes.");
     return NULL;
   }
 
-  script = (char*) malloc(32 + strlen(url) + strlen(host));
+  script = (char*) malloc(32 + strlen(sanitized_url) + strlen(host));
   script[0] = '\0';
-  strcat(script, "FindProxyForURL('");
+  strcat(script, "findProxyForURL('");
   strcat(script, sanitized_url);
   strcat(script, "', '");
   strcat(script, host);
   strcat(script, "')");
   if (_debug()) print_error("DEBUG: Executing JavaScript: %s\n", script);
   if (!JS_EvaluateScript(cx, global, script, strlen(script), NULL, 1, &rval)) {
-    print_error("%s %s\n", error_prefix, "Problem in executing FindProxyForURL.");
+    print_error("%s %s\n", error_prefix, "Problem in executing findProxyForURL.");
     free(sanitized_url);
     free(script);
     return NULL;
